@@ -9,12 +9,8 @@ import symbols
 import qrlogging
 import threading
 
-
+# IConnector realization for Postgres database
 class PostgresConnector(IConnector):
-    """
-    IConnector realization for Postgres database. Uses psycorg2 and connection pools for multi-threaded usage
-    """
-
     def __init__(self, db, user, password, host='localhost', port=5432, schema='public', min_conn=1, max_conn=10):
         """
         configure connection
@@ -30,6 +26,7 @@ class PostgresConnector(IConnector):
         self.min_conn = min_conn
         self.max_conn = max_conn
 
+        self.enable_drop = False
         self.pool = None
         self.__connect()
 
@@ -37,6 +34,10 @@ class PostgresConnector(IConnector):
         if self.pool:
             self.pool.closeall()
 
+    def enable_database_drop(self) -> bool:
+        self.enable_drop = True
+        return True
+
     @retry_log_error()
     def __connect(self):
         self.pool = psycopg2.pool.ThreadedConnectionPool(self.min_conn, self.max_conn, dbname=self.db, user=self.user,
@@ -45,6 +46,9 @@ class PostgresConnector(IConnector):
     def exec(self, request: str, identifiers=None, literals=None, result='all'):
         conn = self.pool.getconn(key=threading.get_ident())
         cursor = conn.cursor()
+        if self.enable_drop:
+            conn.autocommit = True
+            conn.set_isolation_level(0)
         #request = request.replace(symbols.QRDB_IDENTIFIER, '{}')
         request = request.replace(symbols.QRDB_LITERAL, '%s')
         if identifiers:
